pub struct KeepaliveGetState<S> {
pub expires_after: SystemTime,
pub get_state: GetState<S>,
}Expand description
Same as GetState, but additionally tells the receiver that the owner is still alive. If the receiver does not receive this message for a while, it might assume the owner is dead.
Fields
expires_after: SystemTimeThe time at which the actor should be considered expired if no further keepalive is received.
get_state: GetState<S>Trait Implementations
Sourceimpl<S> Bind for KeepaliveGetState<S>where
S: RemoteMessage + Bind,
impl<S> Bind for KeepaliveGetState<S>where
S: RemoteMessage + Bind,
Sourceimpl<S> Clone for KeepaliveGetState<S>where
S: RemoteMessage,
impl<S> Clone for KeepaliveGetState<S>where
S: RemoteMessage,
Sourceimpl<S: Debug> Debug for KeepaliveGetState<S>
impl<S: Debug> Debug for KeepaliveGetState<S>
Sourceimpl<'de, S> Deserialize<'de> for KeepaliveGetState<S>where
S: Deserialize<'de>,
impl<'de, S> Deserialize<'de> for KeepaliveGetState<S>where
S: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Handler<KeepaliveGetState<ActorState>> for ProcAgent
impl Handler<KeepaliveGetState<ActorState>> for ProcAgent
Sourcefn handle<'life0, 'life1, 'async_trait>(
&'life0 mut self,
cx: &'life1 Context<'_, Self>,
message: KeepaliveGetState<ActorState>,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle<'life0, 'life1, 'async_trait>(
&'life0 mut self,
cx: &'life1 Context<'_, Self>,
message: KeepaliveGetState<ActorState>,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Handle the next M-typed message.
Sourceimpl<S: Named> Named for KeepaliveGetState<S>
impl<S: Named> Named for KeepaliveGetState<S>
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
Sourcefn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
Sourcefn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
Sourceimpl<S> Serialize for KeepaliveGetState<S>where
S: Serialize,
impl<S> Serialize for KeepaliveGetState<S>where
S: Serialize,
Sourceimpl<S> Unbind for KeepaliveGetState<S>where
S: RemoteMessage + Unbind,
impl<S> Unbind for KeepaliveGetState<S>where
S: RemoteMessage + Unbind,
impl Accepts<KeepaliveGetState<ActorState>> for ProcAgent
impl RemoteHandles<KeepaliveGetState<ActorState>> for ProcAgent